@@ -274,7 +274,7 @@ def run_netscore(guild_ex, nodes, interactome, output_path, r=3, i=2):
 #source actovate guildmaster &&
 def create_randomized_networks(guild_ex, interactome, output_path, n=100):
     print ('DIO')
-    subprocess.run('bash -c "echo PORCO"')
+    subprocess.run('bash -c "echo PORCO"', shell=True)
     subprocess.run('bash -c "python %s %s %s"' %(guild_ex,interactome,n),
                    shell=True)
     subprocess.run('mv %s.* %s'%(interactome, output_path),shell=True)
@@ -293,7 +293,7 @@ def guild(algorithm, path_guild, nodes, interactome, output_path, out_log, globa
         if len(os.listdir(rand_net))==0:
             print (rand_net, output_path+"/output_netZcore")
             rand_interactomes = create_randomized_networks(path_guild+"/src/create_random_networks_for_netzcore.py", interactome, rand_net)
-        run_netzcore(path_guild, nodes, interactome, rand_net+"/interactome.sif.", output_path+"/output_netZcore")
+        run_netzcore(path_guild, nodes, interactome, rand_net+"/interactome.sif", output_path+"/output_netZcore")
 
 def convert_file(output_file_tc, output_file_c, format_file, out_log=None, global_log=None):
     fu.log("To convert: %s " % (output_file_tc))
